import {BaseEventOrig, Video, VideoProps} from "@tarojs/components";
import {HVideoOptions} from "@/components/video/type";
import Taro from "@tarojs/taro";
import {FC, useState} from "react";
import unique_ident from "@/hooks/unique_ident";

const deviation: number = 1

const HVideo: FC<HVideoOptions> = (opt: HVideoOptions) => {
  const video = Taro.createVideoContext('myVideo')
  const [currentTime, setCurrentTime] = useState(0)

  function onTimeUpdate(event: BaseEventOrig<VideoProps.onTimeUpdateEventDetail>) {
    // if (opt.preview) return;
    const time = event.detail.currentTime
    /** 前进回退 */
    if (currentTime + deviation < time) {
      video.seek(currentTime)
      return
    }
    setCurrentTime(time)

    /** 判断是否进入断点 */
    opt.breakpoint.forEach(d => {
      if (time < d + deviation && time > d - deviation) {
        video.exitFullScreen()
        video.pause()
        video.seek(d - deviation)
        opt.onBreakpoint(d)
        return
      }
    })
  }

  opt.setTime((time: number) => {
    video.seek(time)
    video.play()
  })

  function onEnded() {
    // if (opt.preview) return;
    if (currentTime + 1 > opt.duration) {
      opt.onEnded()
    } else {
      video.seek(currentTime)
      video.play()
    }
  }

  Taro.useUnload(() => {
    unique_ident.put(Number(currentTime.toFixed(2)), Date.now())
  })


  return (
      <Video
        id={'myVideo'}
        autoplay
        style={{width: '100%', height: '100%', position: "relative"}}
        poster={opt?.poster || ''}
        src={opt.src}
        enableProgressGesture={false}
        direction={90}
        onTimeUpdate={onTimeUpdate}
        onEnded={onEnded}
      />
  )
}

export default HVideo
