import {FC, useState} from "react";
import {View} from "@tarojs/components";
import {publicApi} from "@/api/public";
import Taro from "@tarojs/taro";
import Tabs, {OnChangOpt, TabList} from "@/components/tabs/tabs";

interface Props {
  changeTabs: (id: number) => void
}

const CategoryTabs: FC<Props> = ({changeTabs}) => {
  const [tabs, setTabs] = useState<TabList[]>([])

  async function getData() {
    const res = await publicApi.category()
    const data = Object.values(res.categories).reduce((pre, cur) => {
      pre.push(...cur)
      return pre
    }, []).map<TabList>(d => ({title: d.name, value: d.id}))
    setTabs(data)
    changeTabs(data[0].value as number)
  }

  function onChange(data: OnChangOpt) {
    changeTabs(data.tab?.value as number)
  }

  Taro.useLoad(getData)
  return (
    <View className='bg-white'>
      <Tabs tabList={tabs} onChange={onChange}/>
    </View>
  )
}
export default CategoryTabs
