import {Image, Text, View} from "@tarojs/components";
import CategoryTabs from "@/pages/business/history/components/CategoryTabs";
import styles from './history.module.scss'
import Taro from "@tarojs/taro";
import {userApi} from "@/api";
import {useState} from "react";
import {formatMinute} from "@/utils/time";
import Empty from "@/components/empty/empty";

const History = () => {
  const [data, setData] = useState<HourHistory[]>([])

  async function getData(id: number) {
    const res = await userApi.record(id)
    setData(Object.values(res))
  }

  function jump(course_id: number) {
    Taro.navigateTo({url: `/pages/business/curHistory/curHistory?course_id=${course_id}`})
  }

  return (
    <View>
      <CategoryTabs changeTabs={getData}/>

      <View className='mt-3'>
        {data.length ? data.map((d, index) =>
          <View key={index} className={styles.category} onClick={() => jump(d.course_id)}>
            <View className={styles.thumb}>
              <Image src={d.course.thumb} className={styles.image}/>
              <View className={styles.count}>共{d.total_hour_count}节/已学{d.finished_count}节</View>
            </View>
            <View className={styles.text}>
              <View>{d.course.title}</View>
              <View className={styles.describe}>
                <Text className='mr-4'>观看{formatMinute(d.duration)}</Text>
                <Text>学习进度：{(d.finished_count / d.total_hour_count * 100).toFixed(0)}%</Text>
              </View>
            </View>
          </View>) : <Empty name='无观看记录'/>}
      </View>
    </View>
  )
}

export default History
